@@ -30,6 +30,13 @@ lr_parse_generic <- function(filename, decimal = ".", sep = NULL) {
     file = filename, what = character(), quiet = TRUE,
     sep = "\n", skipNul = TRUE
   )
+
+  # Convert to ASCII
+  raw <- iconv(raw, to = "ASCII", sub = "")
+
+  # Remove extra broken character
+  raw <- gsub("\\\001", "", raw)
+
   # substitute separators for a single value to be used in split
   raw <- gsub(seps, ";", raw)
 
