@@ -1,4 +1,4 @@
 if(requireNamespace('spelling', quietly=TRUE))
   spelling::spell_check_test(vignettes = TRUE,
-                             error = FALSE,
+                             error = TRUE,
                              skip_on_cran = TRUE)
